"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.budget_delivery_method_pb2
import google.ads.google_ads.v5.proto.enums.budget_period_pb2
import google.ads.google_ads.v5.proto.enums.budget_status_pb2
import google.ads.google_ads.v5.proto.enums.budget_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DELIVERY_METHOD_FIELD_NUMBER: builtins.int
    EXPLICITLY_SHARED_FIELD_NUMBER: builtins.int
    REFERENCE_COUNT_FIELD_NUMBER: builtins.int
    HAS_RECOMMENDED_BUDGET_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_CLICKS_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_COST_MICROS_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_INTERACTIONS_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_VIEWS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    amount_micros: builtins.int = ...
    total_amount_micros: builtins.int = ...
    status: google.ads.google_ads.v5.proto.enums.budget_status_pb2.BudgetStatusEnum.BudgetStatus.V = (
        ...
    )
    delivery_method: google.ads.google_ads.v5.proto.enums.budget_delivery_method_pb2.BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V = (
        ...
    )
    explicitly_shared: builtins.bool = ...
    reference_count: builtins.int = ...
    has_recommended_budget: builtins.bool = ...
    recommended_budget_amount_micros: builtins.int = ...
    period: google.ads.google_ads.v5.proto.enums.budget_period_pb2.BudgetPeriodEnum.BudgetPeriod.V = (
        ...
    )
    recommended_budget_estimated_change_weekly_clicks: builtins.int = ...
    recommended_budget_estimated_change_weekly_cost_micros: builtins.int = ...
    recommended_budget_estimated_change_weekly_interactions: builtins.int = ...
    recommended_budget_estimated_change_weekly_views: builtins.int = ...
    type: google.ads.google_ads.v5.proto.enums.budget_type_pb2.BudgetTypeEnum.BudgetType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        amount_micros: builtins.int = ...,
        total_amount_micros: builtins.int = ...,
        status: google.ads.google_ads.v5.proto.enums.budget_status_pb2.BudgetStatusEnum.BudgetStatus.V = ...,
        delivery_method: google.ads.google_ads.v5.proto.enums.budget_delivery_method_pb2.BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V = ...,
        explicitly_shared: builtins.bool = ...,
        reference_count: builtins.int = ...,
        has_recommended_budget: builtins.bool = ...,
        recommended_budget_amount_micros: builtins.int = ...,
        period: google.ads.google_ads.v5.proto.enums.budget_period_pb2.BudgetPeriodEnum.BudgetPeriod.V = ...,
        recommended_budget_estimated_change_weekly_clicks: builtins.int = ...,
        recommended_budget_estimated_change_weekly_cost_micros: builtins.int = ...,
        recommended_budget_estimated_change_weekly_interactions: builtins.int = ...,
        recommended_budget_estimated_change_weekly_views: builtins.int = ...,
        type: google.ads.google_ads.v5.proto.enums.budget_type_pb2.BudgetTypeEnum.BudgetType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_amount_micros",
            b"_amount_micros",
            "_explicitly_shared",
            b"_explicitly_shared",
            "_has_recommended_budget",
            b"_has_recommended_budget",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_recommended_budget_amount_micros",
            b"_recommended_budget_amount_micros",
            "_recommended_budget_estimated_change_weekly_clicks",
            b"_recommended_budget_estimated_change_weekly_clicks",
            "_recommended_budget_estimated_change_weekly_cost_micros",
            b"_recommended_budget_estimated_change_weekly_cost_micros",
            "_recommended_budget_estimated_change_weekly_interactions",
            b"_recommended_budget_estimated_change_weekly_interactions",
            "_recommended_budget_estimated_change_weekly_views",
            b"_recommended_budget_estimated_change_weekly_views",
            "_reference_count",
            b"_reference_count",
            "_total_amount_micros",
            b"_total_amount_micros",
            "amount_micros",
            b"amount_micros",
            "explicitly_shared",
            b"explicitly_shared",
            "has_recommended_budget",
            b"has_recommended_budget",
            "id",
            b"id",
            "name",
            b"name",
            "recommended_budget_amount_micros",
            b"recommended_budget_amount_micros",
            "recommended_budget_estimated_change_weekly_clicks",
            b"recommended_budget_estimated_change_weekly_clicks",
            "recommended_budget_estimated_change_weekly_cost_micros",
            b"recommended_budget_estimated_change_weekly_cost_micros",
            "recommended_budget_estimated_change_weekly_interactions",
            b"recommended_budget_estimated_change_weekly_interactions",
            "recommended_budget_estimated_change_weekly_views",
            b"recommended_budget_estimated_change_weekly_views",
            "reference_count",
            b"reference_count",
            "total_amount_micros",
            b"total_amount_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_amount_micros",
            b"_amount_micros",
            "_explicitly_shared",
            b"_explicitly_shared",
            "_has_recommended_budget",
            b"_has_recommended_budget",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_recommended_budget_amount_micros",
            b"_recommended_budget_amount_micros",
            "_recommended_budget_estimated_change_weekly_clicks",
            b"_recommended_budget_estimated_change_weekly_clicks",
            "_recommended_budget_estimated_change_weekly_cost_micros",
            b"_recommended_budget_estimated_change_weekly_cost_micros",
            "_recommended_budget_estimated_change_weekly_interactions",
            b"_recommended_budget_estimated_change_weekly_interactions",
            "_recommended_budget_estimated_change_weekly_views",
            b"_recommended_budget_estimated_change_weekly_views",
            "_reference_count",
            b"_reference_count",
            "_total_amount_micros",
            b"_total_amount_micros",
            "amount_micros",
            b"amount_micros",
            "delivery_method",
            b"delivery_method",
            "explicitly_shared",
            b"explicitly_shared",
            "has_recommended_budget",
            b"has_recommended_budget",
            "id",
            b"id",
            "name",
            b"name",
            "period",
            b"period",
            "recommended_budget_amount_micros",
            b"recommended_budget_amount_micros",
            "recommended_budget_estimated_change_weekly_clicks",
            b"recommended_budget_estimated_change_weekly_clicks",
            "recommended_budget_estimated_change_weekly_cost_micros",
            b"recommended_budget_estimated_change_weekly_cost_micros",
            "recommended_budget_estimated_change_weekly_interactions",
            b"recommended_budget_estimated_change_weekly_interactions",
            "recommended_budget_estimated_change_weekly_views",
            b"recommended_budget_estimated_change_weekly_views",
            "reference_count",
            b"reference_count",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "total_amount_micros",
            b"total_amount_micros",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_amount_micros", b"_amount_micros"],
    ) -> typing_extensions.Literal["amount_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_explicitly_shared", b"_explicitly_shared"
        ],
    ) -> typing_extensions.Literal["explicitly_shared"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_has_recommended_budget", b"_has_recommended_budget"
        ],
    ) -> typing_extensions.Literal["has_recommended_budget"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_recommended_budget_amount_micros", b"_recommended_budget_amount_micros"
        ],
    ) -> typing_extensions.Literal["recommended_budget_amount_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_recommended_budget_estimated_change_weekly_clicks",
            b"_recommended_budget_estimated_change_weekly_clicks",
        ],
    ) -> typing_extensions.Literal[
        "recommended_budget_estimated_change_weekly_clicks"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_recommended_budget_estimated_change_weekly_cost_micros",
            b"_recommended_budget_estimated_change_weekly_cost_micros",
        ],
    ) -> typing_extensions.Literal[
        "recommended_budget_estimated_change_weekly_cost_micros"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_recommended_budget_estimated_change_weekly_interactions",
            b"_recommended_budget_estimated_change_weekly_interactions",
        ],
    ) -> typing_extensions.Literal[
        "recommended_budget_estimated_change_weekly_interactions"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_recommended_budget_estimated_change_weekly_views",
            b"_recommended_budget_estimated_change_weekly_views",
        ],
    ) -> typing_extensions.Literal[
        "recommended_budget_estimated_change_weekly_views"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_reference_count", b"_reference_count"],
    ) -> typing_extensions.Literal["reference_count"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_total_amount_micros", b"_total_amount_micros"
        ],
    ) -> typing_extensions.Literal["total_amount_micros"]: ...

global___CampaignBudget = CampaignBudget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.asset_types_pb2
import google.ads.google_ads.v5.proto.enums.asset_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Asset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_ASSET_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_ASSET_FIELD_NUMBER: builtins.int
    IMAGE_ASSET_FIELD_NUMBER: builtins.int
    TEXT_ASSET_FIELD_NUMBER: builtins.int
    BOOK_ON_GOOGLE_ASSET_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    type: google.ads.google_ads.v5.proto.enums.asset_type_pb2.AssetTypeEnum.AssetType.V = (
        ...
    )
    @property
    def youtube_video_asset(
        self,
    ) -> google.ads.google_ads.v5.proto.common.asset_types_pb2.YoutubeVideoAsset: ...
    @property
    def media_bundle_asset(
        self,
    ) -> google.ads.google_ads.v5.proto.common.asset_types_pb2.MediaBundleAsset: ...
    @property
    def image_asset(
        self,
    ) -> google.ads.google_ads.v5.proto.common.asset_types_pb2.ImageAsset: ...
    @property
    def text_asset(
        self,
    ) -> google.ads.google_ads.v5.proto.common.asset_types_pb2.TextAsset: ...
    @property
    def book_on_google_asset(
        self,
    ) -> google.ads.google_ads.v5.proto.common.asset_types_pb2.BookOnGoogleAsset: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        type: google.ads.google_ads.v5.proto.enums.asset_type_pb2.AssetTypeEnum.AssetType.V = ...,
        youtube_video_asset: typing.Optional[
            google.ads.google_ads.v5.proto.common.asset_types_pb2.YoutubeVideoAsset
        ] = ...,
        media_bundle_asset: typing.Optional[
            google.ads.google_ads.v5.proto.common.asset_types_pb2.MediaBundleAsset
        ] = ...,
        image_asset: typing.Optional[
            google.ads.google_ads.v5.proto.common.asset_types_pb2.ImageAsset
        ] = ...,
        text_asset: typing.Optional[
            google.ads.google_ads.v5.proto.common.asset_types_pb2.TextAsset
        ] = ...,
        book_on_google_asset: typing.Optional[
            google.ads.google_ads.v5.proto.common.asset_types_pb2.BookOnGoogleAsset
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "asset_data",
            b"asset_data",
            "book_on_google_asset",
            b"book_on_google_asset",
            "id",
            b"id",
            "image_asset",
            b"image_asset",
            "media_bundle_asset",
            b"media_bundle_asset",
            "name",
            b"name",
            "text_asset",
            b"text_asset",
            "youtube_video_asset",
            b"youtube_video_asset",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "asset_data",
            b"asset_data",
            "book_on_google_asset",
            b"book_on_google_asset",
            "id",
            b"id",
            "image_asset",
            b"image_asset",
            "media_bundle_asset",
            b"media_bundle_asset",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "text_asset",
            b"text_asset",
            "type",
            b"type",
            "youtube_video_asset",
            b"youtube_video_asset",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["asset_data", b"asset_data"]
    ) -> typing_extensions.Literal[
        "youtube_video_asset",
        "media_bundle_asset",
        "image_asset",
        "text_asset",
        "book_on_google_asset",
    ]: ...

global___Asset = Asset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class InternalErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _InternalError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[InternalError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = InternalErrorEnum.InternalError.V(0)
        UNKNOWN = InternalErrorEnum.InternalError.V(1)
        INTERNAL_ERROR = InternalErrorEnum.InternalError.V(2)
        ERROR_CODE_NOT_PUBLISHED = InternalErrorEnum.InternalError.V(3)
        TRANSIENT_ERROR = InternalErrorEnum.InternalError.V(4)
        DEADLINE_EXCEEDED = InternalErrorEnum.InternalError.V(5)
    class InternalError(metaclass=_InternalError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = InternalErrorEnum.InternalError.V(0)
    UNKNOWN = InternalErrorEnum.InternalError.V(1)
    INTERNAL_ERROR = InternalErrorEnum.InternalError.V(2)
    ERROR_CODE_NOT_PUBLISHED = InternalErrorEnum.InternalError.V(3)
    TRANSIENT_ERROR = InternalErrorEnum.InternalError.V(4)
    DEADLINE_EXCEEDED = InternalErrorEnum.InternalError.V(5)
    def __init__(
        self,
    ) -> None: ...

global___InternalErrorEnum = InternalErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2
import grpc

from .bidding_strategy_service_pb2 import *

class BiddingStrategyServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetBiddingStrategy(
        self,
        request: global___GetBiddingStrategyRequest,
    ) -> google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2.BiddingStrategy: ...
    def MutateBiddingStrategies(
        self,
        request: global___MutateBiddingStrategiesRequest,
    ) -> global___MutateBiddingStrategiesResponse: ...

class BiddingStrategyServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetBiddingStrategy(
        self,
        request: global___GetBiddingStrategyRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2.BiddingStrategy: ...
    @abc.abstractmethod
    def MutateBiddingStrategies(
        self,
        request: global___MutateBiddingStrategiesRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateBiddingStrategiesResponse: ...

def add_BiddingStrategyServiceServicer_to_server(
    servicer: BiddingStrategyServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.custom_parameter_pb2
import google.ads.google_ads.v4.proto.common.feed_common_pb2
import google.ads.google_ads.v4.proto.enums.app_store_pb2
import google.ads.google_ads.v4.proto.enums.call_conversion_reporting_state_pb2
import google.ads.google_ads.v4.proto.enums.price_extension_price_qualifier_pb2
import google.ads.google_ads.v4.proto.enums.price_extension_price_unit_pb2
import google.ads.google_ads.v4.proto.enums.price_extension_type_pb2
import google.ads.google_ads.v4.proto.enums.promotion_extension_discount_modifier_pb2
import google.ads.google_ads.v4.proto.enums.promotion_extension_occasion_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AppFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LINK_TEXT_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    APP_STORE_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    app_store: google.ads.google_ads.v4.proto.enums.app_store_pb2.AppStoreEnum.AppStore.V = (
        ...
    )
    @property
    def link_text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def app_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def final_url_suffix(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        link_text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        app_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        app_store: google.ads.google_ads.v4.proto.enums.app_store_pb2.AppStoreEnum.AppStore.V = ...,
        final_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        final_mobile_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        final_url_suffix: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "app_id",
            b"app_id",
            "final_url_suffix",
            b"final_url_suffix",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "app_id",
            b"app_id",
            "app_store",
            b"app_store",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...

global___AppFeedItem = AppFeedItem

class CallFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    CALL_TRACKING_ENABLED_FIELD_NUMBER: builtins.int
    CALL_CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CALL_CONVERSION_TRACKING_DISABLED_FIELD_NUMBER: builtins.int
    CALL_CONVERSION_REPORTING_STATE_FIELD_NUMBER: builtins.int
    call_conversion_reporting_state: google.ads.google_ads.v4.proto.enums.call_conversion_reporting_state_pb2.CallConversionReportingStateEnum.CallConversionReportingState.V = (
        ...
    )
    @property
    def phone_number(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def call_tracking_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def call_conversion_action(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def call_conversion_tracking_disabled(
        self,
    ) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        phone_number: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        call_tracking_enabled: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        call_conversion_action: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        call_conversion_tracking_disabled: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        call_conversion_reporting_state: google.ads.google_ads.v4.proto.enums.call_conversion_reporting_state_pb2.CallConversionReportingStateEnum.CallConversionReportingState.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_tracking_disabled",
            b"call_conversion_tracking_disabled",
            "call_tracking_enabled",
            b"call_tracking_enabled",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_state",
            b"call_conversion_reporting_state",
            "call_conversion_tracking_disabled",
            b"call_conversion_tracking_disabled",
            "call_tracking_enabled",
            b"call_tracking_enabled",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
        ],
    ) -> None: ...

global___CallFeedItem = CallFeedItem

class CalloutFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CALLOUT_TEXT_FIELD_NUMBER: builtins.int
    @property
    def callout_text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        callout_text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["callout_text", b"callout_text"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["callout_text", b"callout_text"]
    ) -> None: ...

global___CalloutFeedItem = CalloutFeedItem

class LocationFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    ADDRESS_LINE_1_FIELD_NUMBER: builtins.int
    ADDRESS_LINE_2_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    PROVINCE_FIELD_NUMBER: builtins.int
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    @property
    def business_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def address_line_1(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def address_line_2(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def city(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def province(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def postal_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def phone_number(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        business_name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        address_line_1: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        address_line_2: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        city: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        province: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        postal_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        phone_number: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> None: ...

global___LocationFeedItem = LocationFeedItem

class AffiliateLocationFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    ADDRESS_LINE_1_FIELD_NUMBER: builtins.int
    ADDRESS_LINE_2_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    PROVINCE_FIELD_NUMBER: builtins.int
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    CHAIN_NAME_FIELD_NUMBER: builtins.int
    @property
    def business_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def address_line_1(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def address_line_2(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def city(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def province(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def postal_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def phone_number(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def chain_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def chain_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        business_name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        address_line_1: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        address_line_2: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        city: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        province: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        postal_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        phone_number: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        chain_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        chain_name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "chain_id",
            b"chain_id",
            "chain_name",
            b"chain_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "chain_id",
            b"chain_id",
            "chain_name",
            b"chain_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> None: ...

global___AffiliateLocationFeedItem = AffiliateLocationFeedItem

class TextMessageFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    EXTENSION_TEXT_FIELD_NUMBER: builtins.int
    @property
    def business_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def phone_number(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def extension_text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        business_name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        phone_number: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        extension_text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "business_name",
            b"business_name",
            "country_code",
            b"country_code",
            "extension_text",
            b"extension_text",
            "phone_number",
            b"phone_number",
            "text",
            b"text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "business_name",
            b"business_name",
            "country_code",
            b"country_code",
            "extension_text",
            b"extension_text",
            "phone_number",
            b"phone_number",
            "text",
            b"text",
        ],
    ) -> None: ...

global___TextMessageFeedItem = TextMessageFeedItem

class PriceFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    PRICE_QUALIFIER_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    PRICE_OFFERINGS_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v4.proto.enums.price_extension_type_pb2.PriceExtensionTypeEnum.PriceExtensionType.V = (
        ...
    )
    price_qualifier: google.ads.google_ads.v4.proto.enums.price_extension_price_qualifier_pb2.PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier.V = (
        ...
    )
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def price_offerings(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___PriceOffer
    ]: ...
    @property
    def final_url_suffix(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v4.proto.enums.price_extension_type_pb2.PriceExtensionTypeEnum.PriceExtensionType.V = ...,
        price_qualifier: google.ads.google_ads.v4.proto.enums.price_extension_price_qualifier_pb2.PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier.V = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        language_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        price_offerings: typing.Optional[typing.Iterable[global___PriceOffer]] = ...,
        final_url_suffix: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "final_url_suffix",
            b"final_url_suffix",
            "language_code",
            b"language_code",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "final_url_suffix",
            b"final_url_suffix",
            "language_code",
            b"language_code",
            "price_offerings",
            b"price_offerings",
            "price_qualifier",
            b"price_qualifier",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
        ],
    ) -> None: ...

global___PriceFeedItem = PriceFeedItem

class PriceOffer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    unit: google.ads.google_ads.v4.proto.enums.price_extension_price_unit_pb2.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V = (
        ...
    )
    @property
    def header(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def description(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def price(self) -> google.ads.google_ads.v4.proto.common.feed_common_pb2.Money: ...
    @property
    def final_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    def __init__(
        self,
        *,
        header: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        description: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        price: typing.Optional[
            google.ads.google_ads.v4.proto.common.feed_common_pb2.Money
        ] = ...,
        unit: google.ads.google_ads.v4.proto.enums.price_extension_price_unit_pb2.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V = ...,
        final_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        final_mobile_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "description", b"description", "header", b"header", "price", b"price"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "description",
            b"description",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_urls",
            b"final_urls",
            "header",
            b"header",
            "price",
            b"price",
            "unit",
            b"unit",
        ],
    ) -> None: ...

global___PriceOffer = PriceOffer

class PromotionFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROMOTION_TARGET_FIELD_NUMBER: builtins.int
    DISCOUNT_MODIFIER_FIELD_NUMBER: builtins.int
    PROMOTION_START_DATE_FIELD_NUMBER: builtins.int
    PROMOTION_END_DATE_FIELD_NUMBER: builtins.int
    OCCASION_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    PERCENT_OFF_FIELD_NUMBER: builtins.int
    MONEY_AMOUNT_OFF_FIELD_NUMBER: builtins.int
    PROMOTION_CODE_FIELD_NUMBER: builtins.int
    ORDERS_OVER_AMOUNT_FIELD_NUMBER: builtins.int
    discount_modifier: google.ads.google_ads.v4.proto.enums.promotion_extension_discount_modifier_pb2.PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier.V = (
        ...
    )
    occasion: google.ads.google_ads.v4.proto.enums.promotion_extension_occasion_pb2.PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V = (
        ...
    )
    @property
    def promotion_target(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def promotion_start_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def promotion_end_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def final_url_suffix(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def percent_off(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def money_amount_off(
        self,
    ) -> google.ads.google_ads.v4.proto.common.feed_common_pb2.Money: ...
    @property
    def promotion_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def orders_over_amount(
        self,
    ) -> google.ads.google_ads.v4.proto.common.feed_common_pb2.Money: ...
    def __init__(
        self,
        *,
        promotion_target: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        discount_modifier: google.ads.google_ads.v4.proto.enums.promotion_extension_discount_modifier_pb2.PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier.V = ...,
        promotion_start_date: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        promotion_end_date: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        occasion: google.ads.google_ads.v4.proto.enums.promotion_extension_occasion_pb2.PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V = ...,
        final_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        final_mobile_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        final_url_suffix: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        language_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        percent_off: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        money_amount_off: typing.Optional[
            google.ads.google_ads.v4.proto.common.feed_common_pb2.Money
        ] = ...,
        promotion_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        orders_over_amount: typing.Optional[
            google.ads.google_ads.v4.proto.common.feed_common_pb2.Money
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "discount_type",
            b"discount_type",
            "final_url_suffix",
            b"final_url_suffix",
            "language_code",
            b"language_code",
            "money_amount_off",
            b"money_amount_off",
            "orders_over_amount",
            b"orders_over_amount",
            "percent_off",
            b"percent_off",
            "promotion_code",
            b"promotion_code",
            "promotion_end_date",
            b"promotion_end_date",
            "promotion_start_date",
            b"promotion_start_date",
            "promotion_target",
            b"promotion_target",
            "promotion_trigger",
            b"promotion_trigger",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "discount_modifier",
            b"discount_modifier",
            "discount_type",
            b"discount_type",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "language_code",
            b"language_code",
            "money_amount_off",
            b"money_amount_off",
            "occasion",
            b"occasion",
            "orders_over_amount",
            b"orders_over_amount",
            "percent_off",
            b"percent_off",
            "promotion_code",
            b"promotion_code",
            "promotion_end_date",
            b"promotion_end_date",
            "promotion_start_date",
            b"promotion_start_date",
            "promotion_target",
            b"promotion_target",
            "promotion_trigger",
            b"promotion_trigger",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["discount_type", b"discount_type"]
    ) -> typing_extensions.Literal["percent_off", "money_amount_off"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "promotion_trigger", b"promotion_trigger"
        ],
    ) -> typing_extensions.Literal["promotion_code", "orders_over_amount"]: ...

global___PromotionFeedItem = PromotionFeedItem

class StructuredSnippetFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def values(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    def __init__(
        self,
        *,
        header: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        values: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["header", b"header"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["header", b"header", "values", b"values"],
    ) -> None: ...

global___StructuredSnippetFeedItem = StructuredSnippetFeedItem

class SitelinkFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LINK_TEXT_FIELD_NUMBER: builtins.int
    LINE1_FIELD_NUMBER: builtins.int
    LINE2_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    @property
    def link_text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def line1(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def line2(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def final_url_suffix(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        link_text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        line1: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        line2: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        final_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        final_mobile_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        final_url_suffix: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "final_url_suffix",
            b"final_url_suffix",
            "line1",
            b"line1",
            "line2",
            b"line2",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "line1",
            b"line1",
            "line2",
            b"line2",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...

global___SitelinkFeedItem = SitelinkFeedItem

class HotelCalloutFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        language_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "language_code", b"language_code", "text", b"text"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "language_code", b"language_code", "text", b"text"
        ],
    ) -> None: ...

global___HotelCalloutFeedItem = HotelCalloutFeedItem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClickLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CITY_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    METRO_FIELD_NUMBER: builtins.int
    MOST_SPECIFIC_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    city: typing.Text = ...
    country: typing.Text = ...
    metro: typing.Text = ...
    most_specific: typing.Text = ...
    region: typing.Text = ...
    def __init__(
        self,
        *,
        city: typing.Text = ...,
        country: typing.Text = ...,
        metro: typing.Text = ...,
        most_specific: typing.Text = ...,
        region: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_city",
            b"_city",
            "_country",
            b"_country",
            "_metro",
            b"_metro",
            "_most_specific",
            b"_most_specific",
            "_region",
            b"_region",
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_city",
            b"_city",
            "_country",
            b"_country",
            "_metro",
            b"_metro",
            "_most_specific",
            b"_most_specific",
            "_region",
            b"_region",
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_city", b"_city"]
    ) -> typing_extensions.Literal["city"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country", b"_country"]
    ) -> typing_extensions.Literal["country"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_metro", b"_metro"]
    ) -> typing_extensions.Literal["metro"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_most_specific", b"_most_specific"],
    ) -> typing_extensions.Literal["most_specific"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_region", b"_region"]
    ) -> typing_extensions.Literal["region"]: ...

global___ClickLocation = ClickLocation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.policy_pb2
import google.ads.google_ads.v5.proto.common.value_pb2
import google.ads.google_ads.v5.proto.errors.access_invitation_error_pb2
import google.ads.google_ads.v5.proto.errors.account_budget_proposal_error_pb2
import google.ads.google_ads.v5.proto.errors.account_link_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_customizer_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_ad_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_bid_modifier_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_feed_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_parameter_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_sharing_error_pb2
import google.ads.google_ads.v5.proto.errors.adx_error_pb2
import google.ads.google_ads.v5.proto.errors.asset_error_pb2
import google.ads.google_ads.v5.proto.errors.asset_link_error_pb2
import google.ads.google_ads.v5.proto.errors.authentication_error_pb2
import google.ads.google_ads.v5.proto.errors.authorization_error_pb2
import google.ads.google_ads.v5.proto.errors.batch_job_error_pb2
import google.ads.google_ads.v5.proto.errors.bidding_error_pb2
import google.ads.google_ads.v5.proto.errors.bidding_strategy_error_pb2
import google.ads.google_ads.v5.proto.errors.billing_setup_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_budget_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_draft_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_experiment_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_feed_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_shared_set_error_pb2
import google.ads.google_ads.v5.proto.errors.change_status_error_pb2
import google.ads.google_ads.v5.proto.errors.collection_size_error_pb2
import google.ads.google_ads.v5.proto.errors.context_error_pb2
import google.ads.google_ads.v5.proto.errors.conversion_action_error_pb2
import google.ads.google_ads.v5.proto.errors.conversion_adjustment_upload_error_pb2
import google.ads.google_ads.v5.proto.errors.conversion_upload_error_pb2
import google.ads.google_ads.v5.proto.errors.country_code_error_pb2
import google.ads.google_ads.v5.proto.errors.criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.currency_code_error_pb2
import google.ads.google_ads.v5.proto.errors.custom_interest_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_client_link_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_feed_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_manager_link_error_pb2
import google.ads.google_ads.v5.proto.errors.database_error_pb2
import google.ads.google_ads.v5.proto.errors.date_error_pb2
import google.ads.google_ads.v5.proto.errors.date_range_error_pb2
import google.ads.google_ads.v5.proto.errors.distinct_error_pb2
import google.ads.google_ads.v5.proto.errors.enum_error_pb2
import google.ads.google_ads.v5.proto.errors.extension_feed_item_error_pb2
import google.ads.google_ads.v5.proto.errors.extension_setting_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_attribute_reference_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_item_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_item_target_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_item_validation_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_mapping_error_pb2
import google.ads.google_ads.v5.proto.errors.field_error_pb2
import google.ads.google_ads.v5.proto.errors.field_mask_error_pb2
import google.ads.google_ads.v5.proto.errors.function_error_pb2
import google.ads.google_ads.v5.proto.errors.function_parsing_error_pb2
import google.ads.google_ads.v5.proto.errors.geo_target_constant_suggestion_error_pb2
import google.ads.google_ads.v5.proto.errors.header_error_pb2
import google.ads.google_ads.v5.proto.errors.id_error_pb2
import google.ads.google_ads.v5.proto.errors.image_error_pb2
import google.ads.google_ads.v5.proto.errors.internal_error_pb2
import google.ads.google_ads.v5.proto.errors.invoice_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_keyword_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_keyword_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_idea_error_pb2
import google.ads.google_ads.v5.proto.errors.label_error_pb2
import google.ads.google_ads.v5.proto.errors.language_code_error_pb2
import google.ads.google_ads.v5.proto.errors.list_operation_error_pb2
import google.ads.google_ads.v5.proto.errors.manager_link_error_pb2
import google.ads.google_ads.v5.proto.errors.media_bundle_error_pb2
import google.ads.google_ads.v5.proto.errors.media_file_error_pb2
import google.ads.google_ads.v5.proto.errors.media_upload_error_pb2
import google.ads.google_ads.v5.proto.errors.multiplier_error_pb2
import google.ads.google_ads.v5.proto.errors.mutate_error_pb2
import google.ads.google_ads.v5.proto.errors.new_resource_creation_error_pb2
import google.ads.google_ads.v5.proto.errors.not_allowlisted_error_pb2
import google.ads.google_ads.v5.proto.errors.not_empty_error_pb2
import google.ads.google_ads.v5.proto.errors.null_error_pb2
import google.ads.google_ads.v5.proto.errors.offline_user_data_job_error_pb2
import google.ads.google_ads.v5.proto.errors.operation_access_denied_error_pb2
import google.ads.google_ads.v5.proto.errors.operator_error_pb2
import google.ads.google_ads.v5.proto.errors.partial_failure_error_pb2
import google.ads.google_ads.v5.proto.errors.payments_account_error_pb2
import google.ads.google_ads.v5.proto.errors.policy_finding_error_pb2
import google.ads.google_ads.v5.proto.errors.policy_validation_parameter_error_pb2
import google.ads.google_ads.v5.proto.errors.policy_violation_error_pb2
import google.ads.google_ads.v5.proto.errors.query_error_pb2
import google.ads.google_ads.v5.proto.errors.quota_error_pb2
import google.ads.google_ads.v5.proto.errors.range_error_pb2
import google.ads.google_ads.v5.proto.errors.reach_plan_error_pb2
import google.ads.google_ads.v5.proto.errors.recommendation_error_pb2
import google.ads.google_ads.v5.proto.errors.region_code_error_pb2
import google.ads.google_ads.v5.proto.errors.request_error_pb2
import google.ads.google_ads.v5.proto.errors.resource_access_denied_error_pb2
import google.ads.google_ads.v5.proto.errors.resource_count_limit_exceeded_error_pb2
import google.ads.google_ads.v5.proto.errors.setting_error_pb2
import google.ads.google_ads.v5.proto.errors.shared_criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.shared_set_error_pb2
import google.ads.google_ads.v5.proto.errors.size_limit_error_pb2
import google.ads.google_ads.v5.proto.errors.string_format_error_pb2
import google.ads.google_ads.v5.proto.errors.string_length_error_pb2
import google.ads.google_ads.v5.proto.errors.third_party_app_analytics_link_error_pb2
import google.ads.google_ads.v5.proto.errors.time_zone_error_pb2
import google.ads.google_ads.v5.proto.errors.url_field_error_pb2
import google.ads.google_ads.v5.proto.errors.user_data_error_pb2
import google.ads.google_ads.v5.proto.errors.user_list_error_pb2
import google.ads.google_ads.v5.proto.errors.youtube_video_registration_error_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GoogleAdsFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ERRORS_FIELD_NUMBER: builtins.int
    @property
    def errors(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GoogleAdsError
    ]: ...
    def __init__(
        self,
        *,
        errors: typing.Optional[typing.Iterable[global___GoogleAdsError]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["errors", b"errors"]
    ) -> None: ...

global___GoogleAdsFailure = GoogleAdsFailure

class GoogleAdsError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ERROR_CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    @property
    def error_code(self) -> global___ErrorCode: ...
    @property
    def trigger(self) -> google.ads.google_ads.v5.proto.common.value_pb2.Value: ...
    @property
    def location(self) -> global___ErrorLocation: ...
    @property
    def details(self) -> global___ErrorDetails: ...
    def __init__(
        self,
        *,
        error_code: typing.Optional[global___ErrorCode] = ...,
        message: typing.Text = ...,
        trigger: typing.Optional[
            google.ads.google_ads.v5.proto.common.value_pb2.Value
        ] = ...,
        location: typing.Optional[global___ErrorLocation] = ...,
        details: typing.Optional[global___ErrorDetails] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "details",
            b"details",
            "error_code",
            b"error_code",
            "location",
            b"location",
            "trigger",
            b"trigger",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "details",
            b"details",
            "error_code",
            b"error_code",
            "location",
            b"location",
            "message",
            b"message",
            "trigger",
            b"trigger",
        ],
    ) -> None: ...

global___GoogleAdsError = GoogleAdsError

class ErrorCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_ERROR_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_ERROR_FIELD_NUMBER: builtins.int
    URL_FIELD_ERROR_FIELD_NUMBER: builtins.int
    LIST_OPERATION_ERROR_FIELD_NUMBER: builtins.int
    QUERY_ERROR_FIELD_NUMBER: builtins.int
    MUTATE_ERROR_FIELD_NUMBER: builtins.int
    FIELD_MASK_ERROR_FIELD_NUMBER: builtins.int
    AUTHORIZATION_ERROR_FIELD_NUMBER: builtins.int
    INTERNAL_ERROR_FIELD_NUMBER: builtins.int
    QUOTA_ERROR_FIELD_NUMBER: builtins.int
    AD_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_ERROR_FIELD_NUMBER: builtins.int
    AUTHENTICATION_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_ERROR_FIELD_NUMBER: builtins.int
    AD_CUSTOMIZER_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_ERROR_FIELD_NUMBER: builtins.int
    AD_SHARING_ERROR_FIELD_NUMBER: builtins.int
    ADX_ERROR_FIELD_NUMBER: builtins.int
    ASSET_ERROR_FIELD_NUMBER: builtins.int
    BIDDING_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_ERROR_FIELD_NUMBER: builtins.int
    COLLECTION_SIZE_ERROR_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_ERROR_FIELD_NUMBER: builtins.int
    CRITERION_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_ERROR_FIELD_NUMBER: builtins.int
    DATE_ERROR_FIELD_NUMBER: builtins.int
    DATE_RANGE_ERROR_FIELD_NUMBER: builtins.int
    DISTINCT_ERROR_FIELD_NUMBER: builtins.int
    FEED_ATTRIBUTE_REFERENCE_ERROR_FIELD_NUMBER: builtins.int
    FUNCTION_ERROR_FIELD_NUMBER: builtins.int
    FUNCTION_PARSING_ERROR_FIELD_NUMBER: builtins.int
    ID_ERROR_FIELD_NUMBER: builtins.int
    IMAGE_ERROR_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_ERROR_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_ERROR_FIELD_NUMBER: builtins.int
    MEDIA_UPLOAD_ERROR_FIELD_NUMBER: builtins.int
    MEDIA_FILE_ERROR_FIELD_NUMBER: builtins.int
    MULTIPLIER_ERROR_FIELD_NUMBER: builtins.int
    NEW_RESOURCE_CREATION_ERROR_FIELD_NUMBER: builtins.int
    NOT_EMPTY_ERROR_FIELD_NUMBER: builtins.int
    NULL_ERROR_FIELD_NUMBER: builtins.int
    OPERATOR_ERROR_FIELD_NUMBER: builtins.int
    RANGE_ERROR_FIELD_NUMBER: builtins.int
    RECOMMENDATION_ERROR_FIELD_NUMBER: builtins.int
    REGION_CODE_ERROR_FIELD_NUMBER: builtins.int
    SETTING_ERROR_FIELD_NUMBER: builtins.int
    STRING_FORMAT_ERROR_FIELD_NUMBER: builtins.int
    STRING_LENGTH_ERROR_FIELD_NUMBER: builtins.int
    OPERATION_ACCESS_DENIED_ERROR_FIELD_NUMBER: builtins.int
    RESOURCE_ACCESS_DENIED_ERROR_FIELD_NUMBER: builtins.int
    RESOURCE_COUNT_LIMIT_EXCEEDED_ERROR_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_REGISTRATION_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_BID_MODIFIER_ERROR_FIELD_NUMBER: builtins.int
    CONTEXT_ERROR_FIELD_NUMBER: builtins.int
    FIELD_ERROR_FIELD_NUMBER: builtins.int
    SHARED_SET_ERROR_FIELD_NUMBER: builtins.int
    SHARED_CRITERION_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_SHARED_SET_ERROR_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_ERROR_FIELD_NUMBER: builtins.int
    CONVERSION_ADJUSTMENT_UPLOAD_ERROR_FIELD_NUMBER: builtins.int
    CONVERSION_UPLOAD_ERROR_FIELD_NUMBER: builtins.int
    HEADER_ERROR_FIELD_NUMBER: builtins.int
    DATABASE_ERROR_FIELD_NUMBER: builtins.int
    POLICY_FINDING_ERROR_FIELD_NUMBER: builtins.int
    ENUM_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_KEYWORD_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_KEYWORD_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_IDEA_ERROR_FIELD_NUMBER: builtins.int
    ACCOUNT_BUDGET_PROPOSAL_ERROR_FIELD_NUMBER: builtins.int
    USER_LIST_ERROR_FIELD_NUMBER: builtins.int
    CHANGE_STATUS_ERROR_FIELD_NUMBER: builtins.int
    FEED_ERROR_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_SUGGESTION_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_DRAFT_ERROR_FIELD_NUMBER: builtins.int
    FEED_ITEM_ERROR_FIELD_NUMBER: builtins.int
    LABEL_ERROR_FIELD_NUMBER: builtins.int
    BILLING_SETUP_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_CLIENT_LINK_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_MANAGER_LINK_ERROR_FIELD_NUMBER: builtins.int
    FEED_MAPPING_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_FEED_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_FEED_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_FEED_ERROR_FIELD_NUMBER: builtins.int
    CUSTOM_INTEREST_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXPERIMENT_ERROR_FIELD_NUMBER: builtins.int
    EXTENSION_FEED_ITEM_ERROR_FIELD_NUMBER: builtins.int
    AD_PARAMETER_ERROR_FIELD_NUMBER: builtins.int
    FEED_ITEM_VALIDATION_ERROR_FIELD_NUMBER: builtins.int
    EXTENSION_SETTING_ERROR_FIELD_NUMBER: builtins.int
    FEED_ITEM_TARGET_ERROR_FIELD_NUMBER: builtins.int
    POLICY_VIOLATION_ERROR_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    POLICY_VALIDATION_PARAMETER_ERROR_FIELD_NUMBER: builtins.int
    SIZE_LIMIT_ERROR_FIELD_NUMBER: builtins.int
    OFFLINE_USER_DATA_JOB_ERROR_FIELD_NUMBER: builtins.int
    NOT_ALLOWLISTED_ERROR_FIELD_NUMBER: builtins.int
    MANAGER_LINK_ERROR_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_ERROR_FIELD_NUMBER: builtins.int
    ACCESS_INVITATION_ERROR_FIELD_NUMBER: builtins.int
    REACH_PLAN_ERROR_FIELD_NUMBER: builtins.int
    INVOICE_ERROR_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_ERROR_FIELD_NUMBER: builtins.int
    TIME_ZONE_ERROR_FIELD_NUMBER: builtins.int
    ASSET_LINK_ERROR_FIELD_NUMBER: builtins.int
    USER_DATA_ERROR_FIELD_NUMBER: builtins.int
    BATCH_JOB_ERROR_FIELD_NUMBER: builtins.int
    ACCOUNT_LINK_ERROR_FIELD_NUMBER: builtins.int
    THIRD_PARTY_APP_ANALYTICS_LINK_ERROR_FIELD_NUMBER: builtins.int
    request_error: google.ads.google_ads.v5.proto.errors.request_error_pb2.RequestErrorEnum.RequestError.V = (
        ...
    )
    bidding_strategy_error: google.ads.google_ads.v5.proto.errors.bidding_strategy_error_pb2.BiddingStrategyErrorEnum.BiddingStrategyError.V = (
        ...
    )
    url_field_error: google.ads.google_ads.v5.proto.errors.url_field_error_pb2.UrlFieldErrorEnum.UrlFieldError.V = (
        ...
    )
    list_operation_error: google.ads.google_ads.v5.proto.errors.list_operation_error_pb2.ListOperationErrorEnum.ListOperationError.V = (
        ...
    )
    query_error: google.ads.google_ads.v5.proto.errors.query_error_pb2.QueryErrorEnum.QueryError.V = (
        ...
    )
    mutate_error: google.ads.google_ads.v5.proto.errors.mutate_error_pb2.MutateErrorEnum.MutateError.V = (
        ...
    )
    field_mask_error: google.ads.google_ads.v5.proto.errors.field_mask_error_pb2.FieldMaskErrorEnum.FieldMaskError.V = (
        ...
    )
    authorization_error: google.ads.google_ads.v5.proto.errors.authorization_error_pb2.AuthorizationErrorEnum.AuthorizationError.V = (
        ...
    )
    internal_error: google.ads.google_ads.v5.proto.errors.internal_error_pb2.InternalErrorEnum.InternalError.V = (
        ...
    )
    quota_error: google.ads.google_ads.v5.proto.errors.quota_error_pb2.QuotaErrorEnum.QuotaError.V = (
        ...
    )
    ad_error: google.ads.google_ads.v5.proto.errors.ad_error_pb2.AdErrorEnum.AdError.V = (
        ...
    )
    ad_group_error: google.ads.google_ads.v5.proto.errors.ad_group_error_pb2.AdGroupErrorEnum.AdGroupError.V = (
        ...
    )
    campaign_budget_error: google.ads.google_ads.v5.proto.errors.campaign_budget_error_pb2.CampaignBudgetErrorEnum.CampaignBudgetError.V = (
        ...
    )
    campaign_error: google.ads.google_ads.v5.proto.errors.campaign_error_pb2.CampaignErrorEnum.CampaignError.V = (
        ...
    )
    authentication_error: google.ads.google_ads.v5.proto.errors.authentication_error_pb2.AuthenticationErrorEnum.AuthenticationError.V = (
        ...
    )
    ad_group_criterion_error: google.ads.google_ads.v5.proto.errors.ad_group_criterion_error_pb2.AdGroupCriterionErrorEnum.AdGroupCriterionError.V = (
        ...
    )
    ad_customizer_error: google.ads.google_ads.v5.proto.errors.ad_customizer_error_pb2.AdCustomizerErrorEnum.AdCustomizerError.V = (
        ...
    )
    ad_group_ad_error: google.ads.google_ads.v5.proto.errors.ad_group_ad_error_pb2.AdGroupAdErrorEnum.AdGroupAdError.V = (
        ...
    )
    ad_sharing_error: google.ads.google_ads.v5.proto.errors.ad_sharing_error_pb2.AdSharingErrorEnum.AdSharingError.V = (
        ...
    )
    adx_error: google.ads.google_ads.v5.proto.errors.adx_error_pb2.AdxErrorEnum.AdxError.V = (
        ...
    )
    asset_error: google.ads.google_ads.v5.proto.errors.asset_error_pb2.AssetErrorEnum.AssetError.V = (
        ...
    )
    bidding_error: google.ads.google_ads.v5.proto.errors.bidding_error_pb2.BiddingErrorEnum.BiddingError.V = (
        ...
    )
    campaign_criterion_error: google.ads.google_ads.v5.proto.errors.campaign_criterion_error_pb2.CampaignCriterionErrorEnum.CampaignCriterionError.V = (
        ...
    )
    collection_size_error: google.ads.google_ads.v5.proto.errors.collection_size_error_pb2.CollectionSizeErrorEnum.CollectionSizeError.V = (
        ...
    )
    country_code_error: google.ads.google_ads.v5.proto.errors.country_code_error_pb2.CountryCodeErrorEnum.CountryCodeError.V = (
        ...
    )
    criterion_error: google.ads.google_ads.v5.proto.errors.criterion_error_pb2.CriterionErrorEnum.CriterionError.V = (
        ...
    )
    customer_error: google.ads.google_ads.v5.proto.errors.customer_error_pb2.CustomerErrorEnum.CustomerError.V = (
        ...
    )
    date_error: google.ads.google_ads.v5.proto.errors.date_error_pb2.DateErrorEnum.DateError.V = (
        ...
    )
    date_range_error: google.ads.google_ads.v5.proto.errors.date_range_error_pb2.DateRangeErrorEnum.DateRangeError.V = (
        ...
    )
    distinct_error: google.ads.google_ads.v5.proto.errors.distinct_error_pb2.DistinctErrorEnum.DistinctError.V = (
        ...
    )
    feed_attribute_reference_error: google.ads.google_ads.v5.proto.errors.feed_attribute_reference_error_pb2.FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V = (
        ...
    )
    function_error: google.ads.google_ads.v5.proto.errors.function_error_pb2.FunctionErrorEnum.FunctionError.V = (
        ...
    )
    function_parsing_error: google.ads.google_ads.v5.proto.errors.function_parsing_error_pb2.FunctionParsingErrorEnum.FunctionParsingError.V = (
        ...
    )
    id_error: google.ads.google_ads.v5.proto.errors.id_error_pb2.IdErrorEnum.IdError.V = (
        ...
    )
    image_error: google.ads.google_ads.v5.proto.errors.image_error_pb2.ImageErrorEnum.ImageError.V = (
        ...
    )
    language_code_error: google.ads.google_ads.v5.proto.errors.language_code_error_pb2.LanguageCodeErrorEnum.LanguageCodeError.V = (
        ...
    )
    media_bundle_error: google.ads.google_ads.v5.proto.errors.media_bundle_error_pb2.MediaBundleErrorEnum.MediaBundleError.V = (
        ...
    )
    media_upload_error: google.ads.google_ads.v5.proto.errors.media_upload_error_pb2.MediaUploadErrorEnum.MediaUploadError.V = (
        ...
    )
    media_file_error: google.ads.google_ads.v5.proto.errors.media_file_error_pb2.MediaFileErrorEnum.MediaFileError.V = (
        ...
    )
    multiplier_error: google.ads.google_ads.v5.proto.errors.multiplier_error_pb2.MultiplierErrorEnum.MultiplierError.V = (
        ...
    )
    new_resource_creation_error: google.ads.google_ads.v5.proto.errors.new_resource_creation_error_pb2.NewResourceCreationErrorEnum.NewResourceCreationError.V = (
        ...
    )
    not_empty_error: google.ads.google_ads.v5.proto.errors.not_empty_error_pb2.NotEmptyErrorEnum.NotEmptyError.V = (
        ...
    )
    null_error: google.ads.google_ads.v5.proto.errors.null_error_pb2.NullErrorEnum.NullError.V = (
        ...
    )
    operator_error: google.ads.google_ads.v5.proto.errors.operator_error_pb2.OperatorErrorEnum.OperatorError.V = (
        ...
    )
    range_error: google.ads.google_ads.v5.proto.errors.range_error_pb2.RangeErrorEnum.RangeError.V = (
        ...
    )
    recommendation_error: google.ads.google_ads.v5.proto.errors.recommendation_error_pb2.RecommendationErrorEnum.RecommendationError.V = (
        ...
    )
    region_code_error: google.ads.google_ads.v5.proto.errors.region_code_error_pb2.RegionCodeErrorEnum.RegionCodeError.V = (
        ...
    )
    setting_error: google.ads.google_ads.v5.proto.errors.setting_error_pb2.SettingErrorEnum.SettingError.V = (
        ...
    )
    string_format_error: google.ads.google_ads.v5.proto.errors.string_format_error_pb2.StringFormatErrorEnum.StringFormatError.V = (
        ...
    )
    string_length_error: google.ads.google_ads.v5.proto.errors.string_length_error_pb2.StringLengthErrorEnum.StringLengthError.V = (
        ...
    )
    operation_access_denied_error: google.ads.google_ads.v5.proto.errors.operation_access_denied_error_pb2.OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V = (
        ...
    )
    resource_access_denied_error: google.ads.google_ads.v5.proto.errors.resource_access_denied_error_pb2.ResourceAccessDeniedErrorEnum.ResourceAccessDeniedError.V = (
        ...
    )
    resource_count_limit_exceeded_error: google.ads.google_ads.v5.proto.errors.resource_count_limit_exceeded_error_pb2.ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V = (
        ...
    )
    youtube_video_registration_error: google.ads.google_ads.v5.proto.errors.youtube_video_registration_error_pb2.YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V = (
        ...
    )
    ad_group_bid_modifier_error: google.ads.google_ads.v5.proto.errors.ad_group_bid_modifier_error_pb2.AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V = (
        ...
    )
    context_error: google.ads.google_ads.v5.proto.errors.context_error_pb2.ContextErrorEnum.ContextError.V = (
        ...
    )
    field_error: google.ads.google_ads.v5.proto.errors.field_error_pb2.FieldErrorEnum.FieldError.V = (
        ...
    )
    shared_set_error: google.ads.google_ads.v5.proto.errors.shared_set_error_pb2.SharedSetErrorEnum.SharedSetError.V = (
        ...
    )
    shared_criterion_error: google.ads.google_ads.v5.proto.errors.shared_criterion_error_pb2.SharedCriterionErrorEnum.SharedCriterionError.V = (
        ...
    )
    campaign_shared_set_error: google.ads.google_ads.v5.proto.errors.campaign_shared_set_error_pb2.CampaignSharedSetErrorEnum.CampaignSharedSetError.V = (
        ...
    )
    conversion_action_error: google.ads.google_ads.v5.proto.errors.conversion_action_error_pb2.ConversionActionErrorEnum.ConversionActionError.V = (
        ...
    )
    conversion_adjustment_upload_error: google.ads.google_ads.v5.proto.errors.conversion_adjustment_upload_error_pb2.ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V = (
        ...
    )
    conversion_upload_error: google.ads.google_ads.v5.proto.errors.conversion_upload_error_pb2.ConversionUploadErrorEnum.ConversionUploadError.V = (
        ...
    )
    header_error: google.ads.google_ads.v5.proto.errors.header_error_pb2.HeaderErrorEnum.HeaderError.V = (
        ...
    )
    database_error: google.ads.google_ads.v5.proto.errors.database_error_pb2.DatabaseErrorEnum.DatabaseError.V = (
        ...
    )
    policy_finding_error: google.ads.google_ads.v5.proto.errors.policy_finding_error_pb2.PolicyFindingErrorEnum.PolicyFindingError.V = (
        ...
    )
    enum_error: google.ads.google_ads.v5.proto.errors.enum_error_pb2.EnumErrorEnum.EnumError.V = (
        ...
    )
    keyword_plan_error: google.ads.google_ads.v5.proto.errors.keyword_plan_error_pb2.KeywordPlanErrorEnum.KeywordPlanError.V = (
        ...
    )
    keyword_plan_campaign_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_error_pb2.KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V = (
        ...
    )
    keyword_plan_campaign_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_keyword_error_pb2.KeywordPlanCampaignKeywordErrorEnum.KeywordPlanCampaignKeywordError.V = (
        ...
    )
    keyword_plan_ad_group_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_error_pb2.KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupError.V = (
        ...
    )
    keyword_plan_ad_group_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_keyword_error_pb2.KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V = (
        ...
    )
    keyword_plan_idea_error: google.ads.google_ads.v5.proto.errors.keyword_plan_idea_error_pb2.KeywordPlanIdeaErrorEnum.KeywordPlanIdeaError.V = (
        ...
    )
    account_budget_proposal_error: google.ads.google_ads.v5.proto.errors.account_budget_proposal_error_pb2.AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V = (
        ...
    )
    user_list_error: google.ads.google_ads.v5.proto.errors.user_list_error_pb2.UserListErrorEnum.UserListError.V = (
        ...
    )
    change_status_error: google.ads.google_ads.v5.proto.errors.change_status_error_pb2.ChangeStatusErrorEnum.ChangeStatusError.V = (
        ...
    )
    feed_error: google.ads.google_ads.v5.proto.errors.feed_error_pb2.FeedErrorEnum.FeedError.V = (
        ...
    )
    geo_target_constant_suggestion_error: google.ads.google_ads.v5.proto.errors.geo_target_constant_suggestion_error_pb2.GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V = (
        ...
    )
    campaign_draft_error: google.ads.google_ads.v5.proto.errors.campaign_draft_error_pb2.CampaignDraftErrorEnum.CampaignDraftError.V = (
        ...
    )
    feed_item_error: google.ads.google_ads.v5.proto.errors.feed_item_error_pb2.FeedItemErrorEnum.FeedItemError.V = (
        ...
    )
    label_error: google.ads.google_ads.v5.proto.errors.label_error_pb2.LabelErrorEnum.LabelError.V = (
        ...
    )
    billing_setup_error: google.ads.google_ads.v5.proto.errors.billing_setup_error_pb2.BillingSetupErrorEnum.BillingSetupError.V = (
        ...
    )
    customer_client_link_error: google.ads.google_ads.v5.proto.errors.customer_client_link_error_pb2.CustomerClientLinkErrorEnum.CustomerClientLinkError.V = (
        ...
    )
    customer_manager_link_error: google.ads.google_ads.v5.proto.errors.customer_manager_link_error_pb2.CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V = (
        ...
    )
    feed_mapping_error: google.ads.google_ads.v5.proto.errors.feed_mapping_error_pb2.FeedMappingErrorEnum.FeedMappingError.V = (
        ...
    )
    customer_feed_error: google.ads.google_ads.v5.proto.errors.customer_feed_error_pb2.CustomerFeedErrorEnum.CustomerFeedError.V = (
        ...
    )
    ad_group_feed_error: google.ads.google_ads.v5.proto.errors.ad_group_feed_error_pb2.AdGroupFeedErrorEnum.AdGroupFeedError.V = (
        ...
    )
    campaign_feed_error: google.ads.google_ads.v5.proto.errors.campaign_feed_error_pb2.CampaignFeedErrorEnum.CampaignFeedError.V = (
        ...
    )
    custom_interest_error: google.ads.google_ads.v5.proto.errors.custom_interest_error_pb2.CustomInterestErrorEnum.CustomInterestError.V = (
        ...
    )
    campaign_experiment_error: google.ads.google_ads.v5.proto.errors.campaign_experiment_error_pb2.CampaignExperimentErrorEnum.CampaignExperimentError.V = (
        ...
    )
    extension_feed_item_error: google.ads.google_ads.v5.proto.errors.extension_feed_item_error_pb2.ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V = (
        ...
    )
    ad_parameter_error: google.ads.google_ads.v5.proto.errors.ad_parameter_error_pb2.AdParameterErrorEnum.AdParameterError.V = (
        ...
    )
    feed_item_validation_error: google.ads.google_ads.v5.proto.errors.feed_item_validation_error_pb2.FeedItemValidationErrorEnum.FeedItemValidationError.V = (
        ...
    )
    extension_setting_error: google.ads.google_ads.v5.proto.errors.extension_setting_error_pb2.ExtensionSettingErrorEnum.ExtensionSettingError.V = (
        ...
    )
    feed_item_target_error: google.ads.google_ads.v5.proto.errors.feed_item_target_error_pb2.FeedItemTargetErrorEnum.FeedItemTargetError.V = (
        ...
    )
    policy_violation_error: google.ads.google_ads.v5.proto.errors.policy_violation_error_pb2.PolicyViolationErrorEnum.PolicyViolationError.V = (
        ...
    )
    partial_failure_error: google.ads.google_ads.v5.proto.errors.partial_failure_error_pb2.PartialFailureErrorEnum.PartialFailureError.V = (
        ...
    )
    policy_validation_parameter_error: google.ads.google_ads.v5.proto.errors.policy_validation_parameter_error_pb2.PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V = (
        ...
    )
    size_limit_error: google.ads.google_ads.v5.proto.errors.size_limit_error_pb2.SizeLimitErrorEnum.SizeLimitError.V = (
        ...
    )
    offline_user_data_job_error: google.ads.google_ads.v5.proto.errors.offline_user_data_job_error_pb2.OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V = (
        ...
    )
    not_allowlisted_error: google.ads.google_ads.v5.proto.errors.not_allowlisted_error_pb2.NotAllowlistedErrorEnum.NotAllowlistedError.V = (
        ...
    )
    manager_link_error: google.ads.google_ads.v5.proto.errors.manager_link_error_pb2.ManagerLinkErrorEnum.ManagerLinkError.V = (
        ...
    )
    currency_code_error: google.ads.google_ads.v5.proto.errors.currency_code_error_pb2.CurrencyCodeErrorEnum.CurrencyCodeError.V = (
        ...
    )
    access_invitation_error: google.ads.google_ads.v5.proto.errors.access_invitation_error_pb2.AccessInvitationErrorEnum.AccessInvitationError.V = (
        ...
    )
    reach_plan_error: google.ads.google_ads.v5.proto.errors.reach_plan_error_pb2.ReachPlanErrorEnum.ReachPlanError.V = (
        ...
    )
    invoice_error: google.ads.google_ads.v5.proto.errors.invoice_error_pb2.InvoiceErrorEnum.InvoiceError.V = (
        ...
    )
    payments_account_error: google.ads.google_ads.v5.proto.errors.payments_account_error_pb2.PaymentsAccountErrorEnum.PaymentsAccountError.V = (
        ...
    )
    time_zone_error: google.ads.google_ads.v5.proto.errors.time_zone_error_pb2.TimeZoneErrorEnum.TimeZoneError.V = (
        ...
    )
    asset_link_error: google.ads.google_ads.v5.proto.errors.asset_link_error_pb2.AssetLinkErrorEnum.AssetLinkError.V = (
        ...
    )
    user_data_error: google.ads.google_ads.v5.proto.errors.user_data_error_pb2.UserDataErrorEnum.UserDataError.V = (
        ...
    )
    batch_job_error: google.ads.google_ads.v5.proto.errors.batch_job_error_pb2.BatchJobErrorEnum.BatchJobError.V = (
        ...
    )
    account_link_error: google.ads.google_ads.v5.proto.errors.account_link_error_pb2.AccountLinkErrorEnum.AccountLinkError.V = (
        ...
    )
    third_party_app_analytics_link_error: google.ads.google_ads.v5.proto.errors.third_party_app_analytics_link_error_pb2.ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V = (
        ...
    )
    def __init__(
        self,
        *,
        request_error: google.ads.google_ads.v5.proto.errors.request_error_pb2.RequestErrorEnum.RequestError.V = ...,
        bidding_strategy_error: google.ads.google_ads.v5.proto.errors.bidding_strategy_error_pb2.BiddingStrategyErrorEnum.BiddingStrategyError.V = ...,
        url_field_error: google.ads.google_ads.v5.proto.errors.url_field_error_pb2.UrlFieldErrorEnum.UrlFieldError.V = ...,
        list_operation_error: google.ads.google_ads.v5.proto.errors.list_operation_error_pb2.ListOperationErrorEnum.ListOperationError.V = ...,
        query_error: google.ads.google_ads.v5.proto.errors.query_error_pb2.QueryErrorEnum.QueryError.V = ...,
        mutate_error: google.ads.google_ads.v5.proto.errors.mutate_error_pb2.MutateErrorEnum.MutateError.V = ...,
        field_mask_error: google.ads.google_ads.v5.proto.errors.field_mask_error_pb2.FieldMaskErrorEnum.FieldMaskError.V = ...,
        authorization_error: google.ads.google_ads.v5.proto.errors.authorization_error_pb2.AuthorizationErrorEnum.AuthorizationError.V = ...,
        internal_error: google.ads.google_ads.v5.proto.errors.internal_error_pb2.InternalErrorEnum.InternalError.V = ...,
        quota_error: google.ads.google_ads.v5.proto.errors.quota_error_pb2.QuotaErrorEnum.QuotaError.V = ...,
        ad_error: google.ads.google_ads.v5.proto.errors.ad_error_pb2.AdErrorEnum.AdError.V = ...,
        ad_group_error: google.ads.google_ads.v5.proto.errors.ad_group_error_pb2.AdGroupErrorEnum.AdGroupError.V = ...,
        campaign_budget_error: google.ads.google_ads.v5.proto.errors.campaign_budget_error_pb2.CampaignBudgetErrorEnum.CampaignBudgetError.V = ...,
        campaign_error: google.ads.google_ads.v5.proto.errors.campaign_error_pb2.CampaignErrorEnum.CampaignError.V = ...,
        authentication_error: google.ads.google_ads.v5.proto.errors.authentication_error_pb2.AuthenticationErrorEnum.AuthenticationError.V = ...,
        ad_group_criterion_error: google.ads.google_ads.v5.proto.errors.ad_group_criterion_error_pb2.AdGroupCriterionErrorEnum.AdGroupCriterionError.V = ...,
        ad_customizer_error: google.ads.google_ads.v5.proto.errors.ad_customizer_error_pb2.AdCustomizerErrorEnum.AdCustomizerError.V = ...,
        ad_group_ad_error: google.ads.google_ads.v5.proto.errors.ad_group_ad_error_pb2.AdGroupAdErrorEnum.AdGroupAdError.V = ...,
        ad_sharing_error: google.ads.google_ads.v5.proto.errors.ad_sharing_error_pb2.AdSharingErrorEnum.AdSharingError.V = ...,
        adx_error: google.ads.google_ads.v5.proto.errors.adx_error_pb2.AdxErrorEnum.AdxError.V = ...,
        asset_error: google.ads.google_ads.v5.proto.errors.asset_error_pb2.AssetErrorEnum.AssetError.V = ...,
        bidding_error: google.ads.google_ads.v5.proto.errors.bidding_error_pb2.BiddingErrorEnum.BiddingError.V = ...,
        campaign_criterion_error: google.ads.google_ads.v5.proto.errors.campaign_criterion_error_pb2.CampaignCriterionErrorEnum.CampaignCriterionError.V = ...,
        collection_size_error: google.ads.google_ads.v5.proto.errors.collection_size_error_pb2.CollectionSizeErrorEnum.CollectionSizeError.V = ...,
        country_code_error: google.ads.google_ads.v5.proto.errors.country_code_error_pb2.CountryCodeErrorEnum.CountryCodeError.V = ...,
        criterion_error: google.ads.google_ads.v5.proto.errors.criterion_error_pb2.CriterionErrorEnum.CriterionError.V = ...,
        customer_error: google.ads.google_ads.v5.proto.errors.customer_error_pb2.CustomerErrorEnum.CustomerError.V = ...,
        date_error: google.ads.google_ads.v5.proto.errors.date_error_pb2.DateErrorEnum.DateError.V = ...,
        date_range_error: google.ads.google_ads.v5.proto.errors.date_range_error_pb2.DateRangeErrorEnum.DateRangeError.V = ...,
        distinct_error: google.ads.google_ads.v5.proto.errors.distinct_error_pb2.DistinctErrorEnum.DistinctError.V = ...,
        feed_attribute_reference_error: google.ads.google_ads.v5.proto.errors.feed_attribute_reference_error_pb2.FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V = ...,
        function_error: google.ads.google_ads.v5.proto.errors.function_error_pb2.FunctionErrorEnum.FunctionError.V = ...,
        function_parsing_error: google.ads.google_ads.v5.proto.errors.function_parsing_error_pb2.FunctionParsingErrorEnum.FunctionParsingError.V = ...,
        id_error: google.ads.google_ads.v5.proto.errors.id_error_pb2.IdErrorEnum.IdError.V = ...,
        image_error: google.ads.google_ads.v5.proto.errors.image_error_pb2.ImageErrorEnum.ImageError.V = ...,
        language_code_error: google.ads.google_ads.v5.proto.errors.language_code_error_pb2.LanguageCodeErrorEnum.LanguageCodeError.V = ...,
        media_bundle_error: google.ads.google_ads.v5.proto.errors.media_bundle_error_pb2.MediaBundleErrorEnum.MediaBundleError.V = ...,
        media_upload_error: google.ads.google_ads.v5.proto.errors.media_upload_error_pb2.MediaUploadErrorEnum.MediaUploadError.V = ...,
        media_file_error: google.ads.google_ads.v5.proto.errors.media_file_error_pb2.MediaFileErrorEnum.MediaFileError.V = ...,
        multiplier_error: google.ads.google_ads.v5.proto.errors.multiplier_error_pb2.MultiplierErrorEnum.MultiplierError.V = ...,
        new_resource_creation_error: google.ads.google_ads.v5.proto.errors.new_resource_creation_error_pb2.NewResourceCreationErrorEnum.NewResourceCreationError.V = ...,
        not_empty_error: google.ads.google_ads.v5.proto.errors.not_empty_error_pb2.NotEmptyErrorEnum.NotEmptyError.V = ...,
        null_error: google.ads.google_ads.v5.proto.errors.null_error_pb2.NullErrorEnum.NullError.V = ...,
        operator_error: google.ads.google_ads.v5.proto.errors.operator_error_pb2.OperatorErrorEnum.OperatorError.V = ...,
        range_error: google.ads.google_ads.v5.proto.errors.range_error_pb2.RangeErrorEnum.RangeError.V = ...,
        recommendation_error: google.ads.google_ads.v5.proto.errors.recommendation_error_pb2.RecommendationErrorEnum.RecommendationError.V = ...,
        region_code_error: google.ads.google_ads.v5.proto.errors.region_code_error_pb2.RegionCodeErrorEnum.RegionCodeError.V = ...,
        setting_error: google.ads.google_ads.v5.proto.errors.setting_error_pb2.SettingErrorEnum.SettingError.V = ...,
        string_format_error: google.ads.google_ads.v5.proto.errors.string_format_error_pb2.StringFormatErrorEnum.StringFormatError.V = ...,
        string_length_error: google.ads.google_ads.v5.proto.errors.string_length_error_pb2.StringLengthErrorEnum.StringLengthError.V = ...,
        operation_access_denied_error: google.ads.google_ads.v5.proto.errors.operation_access_denied_error_pb2.OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V = ...,
        resource_access_denied_error: google.ads.google_ads.v5.proto.errors.resource_access_denied_error_pb2.ResourceAccessDeniedErrorEnum.ResourceAccessDeniedError.V = ...,
        resource_count_limit_exceeded_error: google.ads.google_ads.v5.proto.errors.resource_count_limit_exceeded_error_pb2.ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V = ...,
        youtube_video_registration_error: google.ads.google_ads.v5.proto.errors.youtube_video_registration_error_pb2.YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V = ...,
        ad_group_bid_modifier_error: google.ads.google_ads.v5.proto.errors.ad_group_bid_modifier_error_pb2.AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V = ...,
        context_error: google.ads.google_ads.v5.proto.errors.context_error_pb2.ContextErrorEnum.ContextError.V = ...,
        field_error: google.ads.google_ads.v5.proto.errors.field_error_pb2.FieldErrorEnum.FieldError.V = ...,
        shared_set_error: google.ads.google_ads.v5.proto.errors.shared_set_error_pb2.SharedSetErrorEnum.SharedSetError.V = ...,
        shared_criterion_error: google.ads.google_ads.v5.proto.errors.shared_criterion_error_pb2.SharedCriterionErrorEnum.SharedCriterionError.V = ...,
        campaign_shared_set_error: google.ads.google_ads.v5.proto.errors.campaign_shared_set_error_pb2.CampaignSharedSetErrorEnum.CampaignSharedSetError.V = ...,
        conversion_action_error: google.ads.google_ads.v5.proto.errors.conversion_action_error_pb2.ConversionActionErrorEnum.ConversionActionError.V = ...,
        conversion_adjustment_upload_error: google.ads.google_ads.v5.proto.errors.conversion_adjustment_upload_error_pb2.ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V = ...,
        conversion_upload_error: google.ads.google_ads.v5.proto.errors.conversion_upload_error_pb2.ConversionUploadErrorEnum.ConversionUploadError.V = ...,
        header_error: google.ads.google_ads.v5.proto.errors.header_error_pb2.HeaderErrorEnum.HeaderError.V = ...,
        database_error: google.ads.google_ads.v5.proto.errors.database_error_pb2.DatabaseErrorEnum.DatabaseError.V = ...,
        policy_finding_error: google.ads.google_ads.v5.proto.errors.policy_finding_error_pb2.PolicyFindingErrorEnum.PolicyFindingError.V = ...,
        enum_error: google.ads.google_ads.v5.proto.errors.enum_error_pb2.EnumErrorEnum.EnumError.V = ...,
        keyword_plan_error: google.ads.google_ads.v5.proto.errors.keyword_plan_error_pb2.KeywordPlanErrorEnum.KeywordPlanError.V = ...,
        keyword_plan_campaign_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_error_pb2.KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V = ...,
        keyword_plan_campaign_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_keyword_error_pb2.KeywordPlanCampaignKeywordErrorEnum.KeywordPlanCampaignKeywordError.V = ...,
        keyword_plan_ad_group_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_error_pb2.KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupError.V = ...,
        keyword_plan_ad_group_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_keyword_error_pb2.KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V = ...,
        keyword_plan_idea_error: google.ads.google_ads.v5.proto.errors.keyword_plan_idea_error_pb2.KeywordPlanIdeaErrorEnum.KeywordPlanIdeaError.V = ...,
        account_budget_proposal_error: google.ads.google_ads.v5.proto.errors.account_budget_proposal_error_pb2.AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V = ...,
        user_list_error: google.ads.google_ads.v5.proto.errors.user_list_error_pb2.UserListErrorEnum.UserListError.V = ...,
        change_status_error: google.ads.google_ads.v5.proto.errors.change_status_error_pb2.ChangeStatusErrorEnum.ChangeStatusError.V = ...,
        feed_error: google.ads.google_ads.v5.proto.errors.feed_error_pb2.FeedErrorEnum.FeedError.V = ...,
        geo_target_constant_suggestion_error: google.ads.google_ads.v5.proto.errors.geo_target_constant_suggestion_error_pb2.GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V = ...,
        campaign_draft_error: google.ads.google_ads.v5.proto.errors.campaign_draft_error_pb2.CampaignDraftErrorEnum.CampaignDraftError.V = ...,
        feed_item_error: google.ads.google_ads.v5.proto.errors.feed_item_error_pb2.FeedItemErrorEnum.FeedItemError.V = ...,
        label_error: google.ads.google_ads.v5.proto.errors.label_error_pb2.LabelErrorEnum.LabelError.V = ...,
        billing_setup_error: google.ads.google_ads.v5.proto.errors.billing_setup_error_pb2.BillingSetupErrorEnum.BillingSetupError.V = ...,
        customer_client_link_error: google.ads.google_ads.v5.proto.errors.customer_client_link_error_pb2.CustomerClientLinkErrorEnum.CustomerClientLinkError.V = ...,
        customer_manager_link_error: google.ads.google_ads.v5.proto.errors.customer_manager_link_error_pb2.CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V = ...,
        feed_mapping_error: google.ads.google_ads.v5.proto.errors.feed_mapping_error_pb2.FeedMappingErrorEnum.FeedMappingError.V = ...,
        customer_feed_error: google.ads.google_ads.v5.proto.errors.customer_feed_error_pb2.CustomerFeedErrorEnum.CustomerFeedError.V = ...,
        ad_group_feed_error: google.ads.google_ads.v5.proto.errors.ad_group_feed_error_pb2.AdGroupFeedErrorEnum.AdGroupFeedError.V = ...,
        campaign_feed_error: google.ads.google_ads.v5.proto.errors.campaign_feed_error_pb2.CampaignFeedErrorEnum.CampaignFeedError.V = ...,
        custom_interest_error: google.ads.google_ads.v5.proto.errors.custom_interest_error_pb2.CustomInterestErrorEnum.CustomInterestError.V = ...,
        campaign_experiment_error: google.ads.google_ads.v5.proto.errors.campaign_experiment_error_pb2.CampaignExperimentErrorEnum.CampaignExperimentError.V = ...,
        extension_feed_item_error: google.ads.google_ads.v5.proto.errors.extension_feed_item_error_pb2.ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V = ...,
        ad_parameter_error: google.ads.google_ads.v5.proto.errors.ad_parameter_error_pb2.AdParameterErrorEnum.AdParameterError.V = ...,
        feed_item_validation_error: google.ads.google_ads.v5.proto.errors.feed_item_validation_error_pb2.FeedItemValidationErrorEnum.FeedItemValidationError.V = ...,
        extension_setting_error: google.ads.google_ads.v5.proto.errors.extension_setting_error_pb2.ExtensionSettingErrorEnum.ExtensionSettingError.V = ...,
        feed_item_target_error: google.ads.google_ads.v5.proto.errors.feed_item_target_error_pb2.FeedItemTargetErrorEnum.FeedItemTargetError.V = ...,
        policy_violation_error: google.ads.google_ads.v5.proto.errors.policy_violation_error_pb2.PolicyViolationErrorEnum.PolicyViolationError.V = ...,
        partial_failure_error: google.ads.google_ads.v5.proto.errors.partial_failure_error_pb2.PartialFailureErrorEnum.PartialFailureError.V = ...,
        policy_validation_parameter_error: google.ads.google_ads.v5.proto.errors.policy_validation_parameter_error_pb2.PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V = ...,
        size_limit_error: google.ads.google_ads.v5.proto.errors.size_limit_error_pb2.SizeLimitErrorEnum.SizeLimitError.V = ...,
        offline_user_data_job_error: google.ads.google_ads.v5.proto.errors.offline_user_data_job_error_pb2.OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V = ...,
        not_allowlisted_error: google.ads.google_ads.v5.proto.errors.not_allowlisted_error_pb2.NotAllowlistedErrorEnum.NotAllowlistedError.V = ...,
        manager_link_error: google.ads.google_ads.v5.proto.errors.manager_link_error_pb2.ManagerLinkErrorEnum.ManagerLinkError.V = ...,
        currency_code_error: google.ads.google_ads.v5.proto.errors.currency_code_error_pb2.CurrencyCodeErrorEnum.CurrencyCodeError.V = ...,
        access_invitation_error: google.ads.google_ads.v5.proto.errors.access_invitation_error_pb2.AccessInvitationErrorEnum.AccessInvitationError.V = ...,
        reach_plan_error: google.ads.google_ads.v5.proto.errors.reach_plan_error_pb2.ReachPlanErrorEnum.ReachPlanError.V = ...,
        invoice_error: google.ads.google_ads.v5.proto.errors.invoice_error_pb2.InvoiceErrorEnum.InvoiceError.V = ...,
        payments_account_error: google.ads.google_ads.v5.proto.errors.payments_account_error_pb2.PaymentsAccountErrorEnum.PaymentsAccountError.V = ...,
        time_zone_error: google.ads.google_ads.v5.proto.errors.time_zone_error_pb2.TimeZoneErrorEnum.TimeZoneError.V = ...,
        asset_link_error: google.ads.google_ads.v5.proto.errors.asset_link_error_pb2.AssetLinkErrorEnum.AssetLinkError.V = ...,
        user_data_error: google.ads.google_ads.v5.proto.errors.user_data_error_pb2.UserDataErrorEnum.UserDataError.V = ...,
        batch_job_error: google.ads.google_ads.v5.proto.errors.batch_job_error_pb2.BatchJobErrorEnum.BatchJobError.V = ...,
        account_link_error: google.ads.google_ads.v5.proto.errors.account_link_error_pb2.AccountLinkErrorEnum.AccountLinkError.V = ...,
        third_party_app_analytics_link_error: google.ads.google_ads.v5.proto.errors.third_party_app_analytics_link_error_pb2.ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "access_invitation_error",
            b"access_invitation_error",
            "account_budget_proposal_error",
            b"account_budget_proposal_error",
            "account_link_error",
            b"account_link_error",
            "ad_customizer_error",
            b"ad_customizer_error",
            "ad_error",
            b"ad_error",
            "ad_group_ad_error",
            b"ad_group_ad_error",
            "ad_group_bid_modifier_error",
            b"ad_group_bid_modifier_error",
            "ad_group_criterion_error",
            b"ad_group_criterion_error",
            "ad_group_error",
            b"ad_group_error",
            "ad_group_feed_error",
            b"ad_group_feed_error",
            "ad_parameter_error",
            b"ad_parameter_error",
            "ad_sharing_error",
            b"ad_sharing_error",
            "adx_error",
            b"adx_error",
            "asset_error",
            b"asset_error",
            "asset_link_error",
            b"asset_link_error",
            "authentication_error",
            b"authentication_error",
            "authorization_error",
            b"authorization_error",
            "batch_job_error",
            b"batch_job_error",
            "bidding_error",
            b"bidding_error",
            "bidding_strategy_error",
            b"bidding_strategy_error",
            "billing_setup_error",
            b"billing_setup_error",
            "campaign_budget_error",
            b"campaign_budget_error",
            "campaign_criterion_error",
            b"campaign_criterion_error",
            "campaign_draft_error",
            b"campaign_draft_error",
            "campaign_error",
            b"campaign_error",
            "campaign_experiment_error",
            b"campaign_experiment_error",
            "campaign_feed_error",
            b"campaign_feed_error",
            "campaign_shared_set_error",
            b"campaign_shared_set_error",
            "change_status_error",
            b"change_status_error",
            "collection_size_error",
            b"collection_size_error",
            "context_error",
            b"context_error",
            "conversion_action_error",
            b"conversion_action_error",
            "conversion_adjustment_upload_error",
            b"conversion_adjustment_upload_error",
            "conversion_upload_error",
            b"conversion_upload_error",
            "country_code_error",
            b"country_code_error",
            "criterion_error",
            b"criterion_error",
            "currency_code_error",
            b"currency_code_error",
            "custom_interest_error",
            b"custom_interest_error",
            "customer_client_link_error",
            b"customer_client_link_error",
            "customer_error",
            b"customer_error",
            "customer_feed_error",
            b"customer_feed_error",
            "customer_manager_link_error",
            b"customer_manager_link_error",
            "database_error",
            b"database_error",
            "date_error",
            b"date_error",
            "date_range_error",
            b"date_range_error",
            "distinct_error",
            b"distinct_error",
            "enum_error",
            b"enum_error",
            "error_code",
            b"error_code",
            "extension_feed_item_error",
            b"extension_feed_item_error",
            "extension_setting_error",
            b"extension_setting_error",
            "feed_attribute_reference_error",
            b"feed_attribute_reference_error",
            "feed_error",
            b"feed_error",
            "feed_item_error",
            b"feed_item_error",
            "feed_item_target_error",
            b"feed_item_target_error",
            "feed_item_validation_error",
            b"feed_item_validation_error",
            "feed_mapping_error",
            b"feed_mapping_error",
            "field_error",
            b"field_error",
            "field_mask_error",
            b"field_mask_error",
            "function_error",
            b"function_error",
            "function_parsing_error",
            b"function_parsing_error",
            "geo_target_constant_suggestion_error",
            b"geo_target_constant_suggestion_error",
            "header_error",
            b"header_error",
            "id_error",
            b"id_error",
            "image_error",
            b"image_error",
            "internal_error",
            b"internal_error",
            "invoice_error",
            b"invoice_error",
            "keyword_plan_ad_group_error",
            b"keyword_plan_ad_group_error",
            "keyword_plan_ad_group_keyword_error",
            b"keyword_plan_ad_group_keyword_error",
            "keyword_plan_campaign_error",
            b"keyword_plan_campaign_error",
            "keyword_plan_campaign_keyword_error",
            b"keyword_plan_campaign_keyword_error",
            "keyword_plan_error",
            b"keyword_plan_error",
            "keyword_plan_idea_error",
            b"keyword_plan_idea_error",
            "label_error",
            b"label_error",
            "language_code_error",
            b"language_code_error",
            "list_operation_error",
            b"list_operation_error",
            "manager_link_error",
            b"manager_link_error",
            "media_bundle_error",
            b"media_bundle_error",
            "media_file_error",
            b"media_file_error",
            "media_upload_error",
            b"media_upload_error",
            "multiplier_error",
            b"multiplier_error",
            "mutate_error",
            b"mutate_error",
            "new_resource_creation_error",
            b"new_resource_creation_error",
            "not_allowlisted_error",
            b"not_allowlisted_error",
            "not_empty_error",
            b"not_empty_error",
            "null_error",
            b"null_error",
            "offline_user_data_job_error",
            b"offline_user_data_job_error",
            "operation_access_denied_error",
            b"operation_access_denied_error",
            "operator_error",
            b"operator_error",
            "partial_failure_error",
            b"partial_failure_error",
            "payments_account_error",
            b"payments_account_error",
            "policy_finding_error",
            b"policy_finding_error",
            "policy_validation_parameter_error",
            b"policy_validation_parameter_error",
            "policy_violation_error",
            b"policy_violation_error",
            "query_error",
            b"query_error",
            "quota_error",
            b"quota_error",
            "range_error",
            b"range_error",
            "reach_plan_error",
            b"reach_plan_error",
            "recommendation_error",
            b"recommendation_error",
            "region_code_error",
            b"region_code_error",
            "request_error",
            b"request_error",
            "resource_access_denied_error",
            b"resource_access_denied_error",
            "resource_count_limit_exceeded_error",
            b"resource_count_limit_exceeded_error",
            "setting_error",
            b"setting_error",
            "shared_criterion_error",
            b"shared_criterion_error",
            "shared_set_error",
            b"shared_set_error",
            "size_limit_error",
            b"size_limit_error",
            "string_format_error",
            b"string_format_error",
            "string_length_error",
            b"string_length_error",
            "third_party_app_analytics_link_error",
            b"third_party_app_analytics_link_error",
            "time_zone_error",
            b"time_zone_error",
            "url_field_error",
            b"url_field_error",
            "user_data_error",
            b"user_data_error",
            "user_list_error",
            b"user_list_error",
            "youtube_video_registration_error",
            b"youtube_video_registration_error",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "access_invitation_error",
            b"access_invitation_error",
            "account_budget_proposal_error",
            b"account_budget_proposal_error",
            "account_link_error",
            b"account_link_error",
            "ad_customizer_error",
            b"ad_customizer_error",
            "ad_error",
            b"ad_error",
            "ad_group_ad_error",
            b"ad_group_ad_error",
            "ad_group_bid_modifier_error",
            b"ad_group_bid_modifier_error",
            "ad_group_criterion_error",
            b"ad_group_criterion_error",
            "ad_group_error",
            b"ad_group_error",
            "ad_group_feed_error",
            b"ad_group_feed_error",
            "ad_parameter_error",
            b"ad_parameter_error",
            "ad_sharing_error",
            b"ad_sharing_error",
            "adx_error",
            b"adx_error",
            "asset_error",
            b"asset_error",
            "asset_link_error",
            b"asset_link_error",
            "authentication_error",
            b"authentication_error",
            "authorization_error",
            b"authorization_error",
            "batch_job_error",
            b"batch_job_error",
            "bidding_error",
            b"bidding_error",
            "bidding_strategy_error",
            b"bidding_strategy_error",
            "billing_setup_error",
            b"billing_setup_error",
            "campaign_budget_error",
            b"campaign_budget_error",
            "campaign_criterion_error",
            b"campaign_criterion_error",
            "campaign_draft_error",
            b"campaign_draft_error",
            "campaign_error",
            b"campaign_error",
            "campaign_experiment_error",
            b"campaign_experiment_error",
            "campaign_feed_error",
            b"campaign_feed_error",
            "campaign_shared_set_error",
            b"campaign_shared_set_error",
            "change_status_error",
            b"change_status_error",
            "collection_size_error",
            b"collection_size_error",
            "context_error",
            b"context_error",
            "conversion_action_error",
            b"conversion_action_error",
            "conversion_adjustment_upload_error",
            b"conversion_adjustment_upload_error",
            "conversion_upload_error",
            b"conversion_upload_error",
            "country_code_error",
            b"country_code_error",
            "criterion_error",
            b"criterion_error",
            "currency_code_error",
            b"currency_code_error",
            "custom_interest_error",
            b"custom_interest_error",
            "customer_client_link_error",
            b"customer_client_link_error",
            "customer_error",
            b"customer_error",
            "customer_feed_error",
            b"customer_feed_error",
            "customer_manager_link_error",
            b"customer_manager_link_error",
            "database_error",
            b"database_error",
            "date_error",
            b"date_error",
            "date_range_error",
            b"date_range_error",
            "distinct_error",
            b"distinct_error",
            "enum_error",
            b"enum_error",
            "error_code",
            b"error_code",
            "extension_feed_item_error",
            b"extension_feed_item_error",
            "extension_setting_error",
            b"extension_setting_error",
            "feed_attribute_reference_error",
            b"feed_attribute_reference_error",
            "feed_error",
            b"feed_error",
            "feed_item_error",
            b"feed_item_error",
            "feed_item_target_error",
            b"feed_item_target_error",
            "feed_item_validation_error",
            b"feed_item_validation_error",
            "feed_mapping_error",
            b"feed_mapping_error",
            "field_error",
            b"field_error",
            "field_mask_error",
            b"field_mask_error",
            "function_error",
            b"function_error",
            "function_parsing_error",
            b"function_parsing_error",
            "geo_target_constant_suggestion_error",
            b"geo_target_constant_suggestion_error",
            "header_error",
            b"header_error",
            "id_error",
            b"id_error",
            "image_error",
            b"image_error",
            "internal_error",
            b"internal_error",
            "invoice_error",
            b"invoice_error",
            "keyword_plan_ad_group_error",
            b"keyword_plan_ad_group_error",
            "keyword_plan_ad_group_keyword_error",
            b"keyword_plan_ad_group_keyword_error",
            "keyword_plan_campaign_error",
            b"keyword_plan_campaign_error",
            "keyword_plan_campaign_keyword_error",
            b"keyword_plan_campaign_keyword_error",
            "keyword_plan_error",
            b"keyword_plan_error",
            "keyword_plan_idea_error",
            b"keyword_plan_idea_error",
            "label_error",
            b"label_error",
            "language_code_error",
            b"language_code_error",
            "list_operation_error",
            b"list_operation_error",
            "manager_link_error",
            b"manager_link_error",
            "media_bundle_error",
            b"media_bundle_error",
            "media_file_error",
            b"media_file_error",
            "media_upload_error",
            b"media_upload_error",
            "multiplier_error",
            b"multiplier_error",
            "mutate_error",
            b"mutate_error",
            "new_resource_creation_error",
            b"new_resource_creation_error",
            "not_allowlisted_error",
            b"not_allowlisted_error",
            "not_empty_error",
            b"not_empty_error",
            "null_error",
            b"null_error",
            "offline_user_data_job_error",
            b"offline_user_data_job_error",
            "operation_access_denied_error",
            b"operation_access_denied_error",
            "operator_error",
            b"operator_error",
            "partial_failure_error",
            b"partial_failure_error",
            "payments_account_error",
            b"payments_account_error",
            "policy_finding_error",
            b"policy_finding_error",
            "policy_validation_parameter_error",
            b"policy_validation_parameter_error",
            "policy_violation_error",
            b"policy_violation_error",
            "query_error",
            b"query_error",
            "quota_error",
            b"quota_error",
            "range_error",
            b"range_error",
            "reach_plan_error",
            b"reach_plan_error",
            "recommendation_error",
            b"recommendation_error",
            "region_code_error",
            b"region_code_error",
            "request_error",
            b"request_error",
            "resource_access_denied_error",
            b"resource_access_denied_error",
            "resource_count_limit_exceeded_error",
            b"resource_count_limit_exceeded_error",
            "setting_error",
            b"setting_error",
            "shared_criterion_error",
            b"shared_criterion_error",
            "shared_set_error",
            b"shared_set_error",
            "size_limit_error",
            b"size_limit_error",
            "string_format_error",
            b"string_format_error",
            "string_length_error",
            b"string_length_error",
            "third_party_app_analytics_link_error",
            b"third_party_app_analytics_link_error",
            "time_zone_error",
            b"time_zone_error",
            "url_field_error",
            b"url_field_error",
            "user_data_error",
            b"user_data_error",
            "user_list_error",
            b"user_list_error",
            "youtube_video_registration_error",
            b"youtube_video_registration_error",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["error_code", b"error_code"]
    ) -> typing_extensions.Literal[
        "request_error",
        "bidding_strategy_error",
        "url_field_error",
        "list_operation_error",
        "query_error",
        "mutate_error",
        "field_mask_error",
        "authorization_error",
        "internal_error",
        "quota_error",
        "ad_error",
        "ad_group_error",
        "campaign_budget_error",
        "campaign_error",
        "authentication_error",
        "ad_group_criterion_error",
        "ad_customizer_error",
        "ad_group_ad_error",
        "ad_sharing_error",
        "adx_error",
        "asset_error",
        "bidding_error",
        "campaign_criterion_error",
        "collection_size_error",
        "country_code_error",
        "criterion_error",
        "customer_error",
        "date_error",
        "date_range_error",
        "distinct_error",
        "feed_attribute_reference_error",
        "function_error",
        "function_parsing_error",
        "id_error",
        "image_error",
        "language_code_error",
        "media_bundle_error",
        "media_upload_error",
        "media_file_error",
        "multiplier_error",
        "new_resource_creation_error",
        "not_empty_error",
        "null_error",
        "operator_error",
        "range_error",
        "recommendation_error",
        "region_code_error",
        "setting_error",
        "string_format_error",
        "string_length_error",
        "operation_access_denied_error",
        "resource_access_denied_error",
        "resource_count_limit_exceeded_error",
        "youtube_video_registration_error",
        "ad_group_bid_modifier_error",
        "context_error",
        "field_error",
        "shared_set_error",
        "shared_criterion_error",
        "campaign_shared_set_error",
        "conversion_action_error",
        "conversion_adjustment_upload_error",
        "conversion_upload_error",
        "header_error",
        "database_error",
        "policy_finding_error",
        "enum_error",
        "keyword_plan_error",
        "keyword_plan_campaign_error",
        "keyword_plan_campaign_keyword_error",
        "keyword_plan_ad_group_error",
        "keyword_plan_ad_group_keyword_error",
        "keyword_plan_idea_error",
        "account_budget_proposal_error",
        "user_list_error",
        "change_status_error",
        "feed_error",
        "geo_target_constant_suggestion_error",
        "campaign_draft_error",
        "feed_item_error",
        "label_error",
        "billing_setup_error",
        "customer_client_link_error",
        "customer_manager_link_error",
        "feed_mapping_error",
        "customer_feed_error",
        "ad_group_feed_error",
        "campaign_feed_error",
        "custom_interest_error",
        "campaign_experiment_error",
        "extension_feed_item_error",
        "ad_parameter_error",
        "feed_item_validation_error",
        "extension_setting_error",
        "feed_item_target_error",
        "policy_violation_error",
        "partial_failure_error",
        "policy_validation_parameter_error",
        "size_limit_error",
        "offline_user_data_job_error",
        "not_allowlisted_error",
        "manager_link_error",
        "currency_code_error",
        "access_invitation_error",
        "reach_plan_error",
        "invoice_error",
        "payments_account_error",
        "time_zone_error",
        "asset_link_error",
        "user_data_error",
        "batch_job_error",
        "account_link_error",
        "third_party_app_analytics_link_error",
    ]: ...

global___ErrorCode = ErrorCode

class ErrorLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class FieldPathElement(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FIELD_NAME_FIELD_NUMBER: builtins.int
        INDEX_FIELD_NUMBER: builtins.int
        field_name: typing.Text = ...
        @property
        def index(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            field_name: typing.Text = ...,
            index: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["index", b"index"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "field_name", b"field_name", "index", b"index"
            ],
        ) -> None: ...
    FIELD_PATH_ELEMENTS_FIELD_NUMBER: builtins.int
    @property
    def field_path_elements(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ErrorLocation.FieldPathElement
    ]: ...
    def __init__(
        self,
        *,
        field_path_elements: typing.Optional[
            typing.Iterable[global___ErrorLocation.FieldPathElement]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "field_path_elements", b"field_path_elements"
        ],
    ) -> None: ...

global___ErrorLocation = ErrorLocation

class ErrorDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UNPUBLISHED_ERROR_CODE_FIELD_NUMBER: builtins.int
    POLICY_VIOLATION_DETAILS_FIELD_NUMBER: builtins.int
    POLICY_FINDING_DETAILS_FIELD_NUMBER: builtins.int
    QUOTA_ERROR_DETAILS_FIELD_NUMBER: builtins.int
    unpublished_error_code: typing.Text = ...
    @property
    def policy_violation_details(self) -> global___PolicyViolationDetails: ...
    @property
    def policy_finding_details(self) -> global___PolicyFindingDetails: ...
    @property
    def quota_error_details(self) -> global___QuotaErrorDetails: ...
    def __init__(
        self,
        *,
        unpublished_error_code: typing.Text = ...,
        policy_violation_details: typing.Optional[
            global___PolicyViolationDetails
        ] = ...,
        policy_finding_details: typing.Optional[global___PolicyFindingDetails] = ...,
        quota_error_details: typing.Optional[global___QuotaErrorDetails] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "policy_finding_details",
            b"policy_finding_details",
            "policy_violation_details",
            b"policy_violation_details",
            "quota_error_details",
            b"quota_error_details",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "policy_finding_details",
            b"policy_finding_details",
            "policy_violation_details",
            b"policy_violation_details",
            "quota_error_details",
            b"quota_error_details",
            "unpublished_error_code",
            b"unpublished_error_code",
        ],
    ) -> None: ...

global___ErrorDetails = ErrorDetails

class PolicyViolationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTERNAL_POLICY_DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    EXTERNAL_POLICY_NAME_FIELD_NUMBER: builtins.int
    IS_EXEMPTIBLE_FIELD_NUMBER: builtins.int
    external_policy_description: typing.Text = ...
    external_policy_name: typing.Text = ...
    is_exemptible: builtins.bool = ...
    @property
    def key(
        self,
    ) -> google.ads.google_ads.v5.proto.common.policy_pb2.PolicyViolationKey: ...
    def __init__(
        self,
        *,
        external_policy_description: typing.Text = ...,
        key: typing.Optional[
            google.ads.google_ads.v5.proto.common.policy_pb2.PolicyViolationKey
        ] = ...,
        external_policy_name: typing.Text = ...,
        is_exemptible: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["key", b"key"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "external_policy_description",
            b"external_policy_description",
            "external_policy_name",
            b"external_policy_name",
            "is_exemptible",
            b"is_exemptible",
            "key",
            b"key",
        ],
    ) -> None: ...

global___PolicyViolationDetails = PolicyViolationDetails

class PolicyFindingDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "policy_topic_entries", b"policy_topic_entries"
        ],
    ) -> None: ...

global___PolicyFindingDetails = PolicyFindingDetails

class QuotaErrorDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QuotaRateScope(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QuotaRateScope.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QuotaErrorDetails.QuotaRateScope.V(0)
        UNKNOWN = QuotaErrorDetails.QuotaRateScope.V(1)
        ACCOUNT = QuotaErrorDetails.QuotaRateScope.V(2)
        DEVELOPER = QuotaErrorDetails.QuotaRateScope.V(3)
    class QuotaRateScope(metaclass=_QuotaRateScope):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QuotaErrorDetails.QuotaRateScope.V(0)
    UNKNOWN = QuotaErrorDetails.QuotaRateScope.V(1)
    ACCOUNT = QuotaErrorDetails.QuotaRateScope.V(2)
    DEVELOPER = QuotaErrorDetails.QuotaRateScope.V(3)

    RATE_SCOPE_FIELD_NUMBER: builtins.int
    RATE_NAME_FIELD_NUMBER: builtins.int
    RETRY_DELAY_FIELD_NUMBER: builtins.int
    rate_scope: global___QuotaErrorDetails.QuotaRateScope.V = ...
    rate_name: typing.Text = ...
    @property
    def retry_delay(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        rate_scope: global___QuotaErrorDetails.QuotaRateScope.V = ...,
        rate_name: typing.Text = ...,
        retry_delay: typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["retry_delay", b"retry_delay"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "rate_name",
            b"rate_name",
            "rate_scope",
            b"rate_scope",
            "retry_delay",
            b"retry_delay",
        ],
    ) -> None: ...

global___QuotaErrorDetails = QuotaErrorDetails
